Index: chrome/browser/cocoa/delayedmenu_button_unittest.mm |
diff --git a/chrome/browser/cocoa/delayedmenu_button_unittest.mm b/chrome/browser/cocoa/delayedmenu_button_unittest.mm |
index b04cb27c7dedf62805218127477b5aaf863579c2..a9eaa7f01043d0b85b6817d9552c411a5b17f284 100644 |
--- a/chrome/browser/cocoa/delayedmenu_button_unittest.mm |
+++ b/chrome/browser/cocoa/delayedmenu_button_unittest.mm |
@@ -52,16 +52,17 @@ TEST_F(DelayedMenuButtonTest, MenuAssign) { |
[menu insertItemWithTitle:@"bar" action:nil keyEquivalent:@"" atIndex:2]; |
[menu insertItemWithTitle:@"baz" action:nil keyEquivalent:@"" atIndex:3]; |
- [button_ setMenu:menu]; |
- EXPECT_TRUE([button_ menu]); |
+ [button_ setAttachedMenu:menu]; |
+ EXPECT_TRUE([button_ attachedMenu]); |
- [button_ setMenuEnabled:YES]; |
- EXPECT_TRUE([button_ menuEnabled]); |
+ [button_ setAttachedMenuEnabled:YES]; |
+ EXPECT_TRUE([button_ attachedMenuEnabled]); |
// TODO(viettrungluu): Display the menu. (Calling DelayedMenuButton's private |
// |-menuAction:| method displays it fine, but the problem is getting rid of |
// the menu. We can catch the |NSMenuDidBeginTrackingNotification| from |menu| |
// fine, but then |-cancelTracking| doesn't dismiss it. I don't know why.) |
} |
// TODO(viettrungluu): Test the two actions of the button (the normal one and |
@@ -52,16 +52,17 @@ TEST_F(DelayedMenuButtonTest, MenuAssign) { |
// TODO(viettrungluu): Display the menu. (Calling DelayedMenuButton's private |
- // |-menuAction:| method displays it fine, but the problem is getting rid of |
- // the menu. We can catch the |NSMenuDidBeginTrackingNotification| from |menu| |
- // fine, but then |-cancelTracking| doesn't dismiss it. I don't know why.) |
+ // |-attachedMenuAction:| method displays it fine, but the problem is |
+ // getting rid of the menu. We can catch the |
+ // |NSMenuDidBeginTrackingNotification| from |menu| fine, but then |
+ // |-cancelTracking| doesn't dismiss it. I don't know why.) |
} |
// TODO(viettrungluu): Test the two actions of the button (the normal one and |